
/* ===========================================================================
 * Modulo:  matriz.h
 *
 * Version: 1.0 (23/11/2017)
 *
 * Autor:   Ivan Cantador Gutierrez, ivan.cantador@uam.es
 *          Departamento de Ingenieria Informatica
 *          Escuela Politecnica Superior - Universidad Autonoma de Madrid
 * =========================================================================== */


 #ifndef _MATRIZ_H_
#define _MATRIZ_H_


/* ------------------------------------------ */
/* Definicion publica de estructuras de datos */
/* ------------------------------------------ */

/* Estructura de datos asociada al TAD Matriz */
typedef struct
{
	int		numeroFilas;

	int		numeroColumnas;

	double	**elementos;

} Matriz;


/* --------------------------------- */
/* Declaracion de funciones publicas */
/* --------------------------------- */

/*****************************************************************************
 * Funcion: matriz_crear
 * 
 * Descripcion: 
 *    Crea una matriz de dimension definida por los argumentos de entrada,
 *    e inicializa sus elementos a 0.
 *
 * Argumentos de entrada:
 *    - numeroFilas
 *         numero de filas de la matriz a crear
 *    - numeroColumnas
 *         numero de columnas de la matriz a crear
 *
 * Salida:
 *    - puntero a la matriz crada, NULL en caso de error
 *****************************************************************************/

Matriz *matriz_crear( int numeroFilas, int numeroColumnas );

/*****************************************************************************
 * Funcion: matriz_inicializar
 * 
 * Descripcion: 
 *    Inicializa el contenido de una matriz con unos valores dados.
 *
 * Argumentos de entrada:
 *    - matriz
 *         matriz a inicializar
 *    - valores
 *         array con los valores a copiar en la matriz
 *
 * Salida:
 *    - 0 si la ejecucion se realizo con exito, -1 en caso contrario
 *****************************************************************************/

int	matriz_inicializar( Matriz *matriz, double **valores );

/*****************************************************************************
 * Funcion: matriz_visualizar
 * 
 * Descripcion: 
 *    Escribe en un fichero dado el contenido de una matriz.
 *
 * Argumentos de entrada:
 *    - matriz
 *         matriz a visualizar
 *    - fichero
 *         fichero donde escribir el contenido de la matriz
 *
 * Salida:
 *    - 0 si la ejecucion se realizo con exito, -1 en caso contrario
 *****************************************************************************/

int	matriz_visualizar( Matriz *matriz, FILE *fichero );

/*****************************************************************************
 * Funcion: matriz_liberar
 * 
 * Descripcion: 
 *    Libera la memoria reservada para una matriz dada.
 *
 * Argumentos de entrada:
 *    - matriz
 *         matriz a liberar
 *
 * Salida:
 *    - (ninguna)
 *****************************************************************************/

void matriz_liberar( Matriz *matriz );


#endif
